import express, {Router} from 'express';
import 'express-async-errors';
import cors from 'cors';
import rateLimit from 'express-rate-limit';
import {handleError, ValidationError} from "./utils/errors";
import {adRouter} from "./routers/ad.router";
import {config} from "./config/config";

const app = express();

app.use(cors({
    origin: config.corsOrigin,
}));
app.use(express.json());
app.use(rateLimit({
    windowMs: 5 * 60 * 1000, // 5 minutes
    max: 100, // Limit each IP to 100 requests per `window` (here, per 15 minutes)
}));

// //wystarczyłoby coś takiego, czyli dodać /api przed dotychczasową ścieżką
// //bo router i tak czyta to co jest za tą ścieżką
// app.use('/api/ad', adRouter);

//ale Kuba pokazuje inny sposób jak przepisać wszystkie ścieżki
const router = Router();
router.use('/ad', adRouter);
app.use('/api', router);

app.use(handleError);

app.listen(config.listenPort, config.listenHost, () => {
    console.log('Server working...');
});